/*
 * Copyright (c) 1991-2023 by STEP Tools Inc. 
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and
 * its documentation is hereby granted, provided that this copyright
 * notice and license appear on all copies of the software.
 * 
 * STEP TOOLS MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
 * SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT. STEP TOOLS
 * SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A
 * RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS
 * DERIVATIVES.
 *
 * Author: Dave Loffredo (loffredo@steptools.com)
 */

//----------------------------------------
// GEOMETRY UTILITIES  -- 
//

// STEP ASSEMBLIES -- STEP assembly relationships are constructed on
// two levels, relating the configuration management instances and
// another relating the geometry.  
//
// Instances of shape_definition_representation (SDR) join the
// configuration management data and the geometry.
//

// Given two product_definitions this creates an assembly between them.
stp_next_assembly_usage_occurrence* createCMAsm(
    const char* asm_id,
    const char* asm_usage,
    const char* asm_desc,
    const char* ref_desig, 
    stp_product_definition* asm_pdef, 
    stp_product_definition* comp_pdef
    );

// Used for relating two shape_representations of the same type.
// Given two shape_representations and their axis2_placements, this
// creates the geometric portion of the assembly using a mapped_item.
void createGeomAsmMI(
    stp_representation* asmSR, 
    stp_representation_item* asmAxis,
    stp_representation* compSR,
    stp_representation_item* compAxis,
    stp_next_assembly_usage_occurrence* nauo
    ); 

// Used for relating two shape_representations of different types.
// Given two shape_reps and their axis2_placements, this creates the
// geometric portion of the assembly using a
// context_dependent_shape_representation.
void createGeomAsmCDSR(
    stp_representation* asmSR, 
    stp_representation_item* asmAxis,
    stp_representation* compSR,
    stp_representation_item* compAxis,
    stp_next_assembly_usage_occurrence* nauo
    ); 

// Find the product_definition that a property is attached to.  Note
// that properties can be attached to other things besides a product
// definition.
//
stp_product_definition * get_property_pdef (
    stp_property_definition_representation * pdr
    );
